@@ -39,6 +39,7 @@ class Droplet(BaseAPI):
         user_data (str): arbitrary data to pass to droplet
         volumes (:obj:`str`, optional): list of blockstorage volumes
         monitoring (bool): True if installing the DigitalOcean monitoring agent
+        vpc_uuid (str, optional): ID of a VPC in which the Droplet will be created
 
     Attributes returned by API:
         * id (int): droplet id
@@ -61,7 +62,7 @@ class Droplet(BaseAPI):
         * ip_v6_address (:obj:`str`, optional): list of ipv6 addresses assigned
         * end_point (str): url of api endpoint used
         * volume_ids (:obj:`str`, optional): list of blockstorage volumes
-
+        * vpc_uuid (str, optional): ID of the VPC that the Droplet is assigned to
     """
 
     def __init__(self, *args, **kwargs):
@@ -94,6 +95,7 @@ class Droplet(BaseAPI):
         self.volumes = []
         self.tags = []
         self.monitoring = None
+        self.vpc_uuid = None
 
         # This will load also the values passed
         super(Droplet, self).__init__(*args, **kwargs)
@@ -124,6 +126,7 @@ class Droplet(BaseAPI):
             "private_networking": bool(kwargs.get("private_networking")),
             "tags": kwargs.get("tags"),
             "monitoring": bool(kwargs.get("monitoring")),
+            "vpc_uuid": kwargs.get("vpc_uuid"),
         }
 
         if kwargs.get("ssh_keys"):
@@ -223,7 +226,7 @@ class Droplet(BaseAPI):
             return action
         else:
             action = action[u'action']
-            return_action = Action(token=self.token)
+            return_action = Action(token=self.tokens)
             # Loading attributes
             for attr in action.keys():
                 setattr(return_action, attr, action[attr])
@@ -556,6 +559,7 @@ class Droplet(BaseAPI):
             "volumes": self.volumes,
             "tags": self.tags,
             "monitoring": bool(self.monitoring),
+            "vpc_uuid": self.vpc_uuid,
         }
 
         if self.user_data:
@@ -586,7 +590,7 @@ class Droplet(BaseAPI):
         actions = []
         for action_dict in answer['actions']:
             action = Action(**action_dict)
-            action.token = self.token
+            action.token = self.tokens
             action.droplet_id = self.id
             action.load()
             actions.append(action)
@@ -599,7 +603,7 @@ class Droplet(BaseAPI):
             action_id (int): id of action
         """
         return Action.get_object(
-            api_token=self.token,
+            api_token=self.tokens,
             action_id=action_id
         )
 
@@ -612,7 +616,7 @@ class Droplet(BaseAPI):
         for id in self.snapshot_ids:
             snapshot = Image()
             snapshot.id = id
-            snapshot.token = self.token
+            snapshot.token = self.tokens
             snapshots.append(snapshot)
         return snapshots
 
@@ -626,7 +630,7 @@ class Droplet(BaseAPI):
         while True:
             for jsond in data[u'kernels']:
                 kernel = Kernel(**jsond)
-                kernel.token = self.token
+                kernel.token = self.tokens
                 kernels.append(kernel)
             try:
                 url = data[u'links'][u'pages'].get(u'next')
@@ -649,7 +653,7 @@ class Droplet(BaseAPI):
         self.volumes = list()
 
         for volume_id in self.volume_ids:
-            volume = Volume().get_object(self.token, volume_id)
+            volume = Volume().get_object(self.tokens, volume_id)
             self.volumes.append(volume)
 
 
